parse_message

Function parse_message 

pub fn parse_message(input: &[u8]) -> Message<'_>
Parse a whole email including its (MIME) body

Arguments

  • input - A buffer of bytes containing your full email

Returns

  • msg - The parsed message

Examples

let input = br#"Date: 7 Mar 2023 08:00:00 +0200
From: deuxfleurs@example.com
To: someone_else@example.com
Subject: An RFC 822 formatted message
MIME-Version: 1.0
Content-Type: text/plain; charset=us-ascii

This is the plain text body of the message. Note the blank line
between the header information and the body of the message."#;

let email = eml_codec::parse_message(input);
println!(
    "{} message structure is:\n{:#?}",
    email.imf.from_or_sender().unwrap().to_string(),
    email,
);