raw_headers

Function raw_headers 

pub fn raw_headers(input: &[u8]) -> &[u8] 
Get the raw subslice of the input that corresponds to the header section.

It can be later parsed using parse_imf or parse_message (resulting in an empty body). This is equivalent to directly parsing the full input, but allows the header section to e.g. be stored separately without storing the body.