pub enum InvalidField {
Name,
Body,
NeedsDiscard,
}Variants
Name
The field name is not a known IMF field
Body
The field body could not be parsed
NeedsDiscard
The field could be parsed but represents a dummy value that is not part of the RFC-strict syntax. It must be discarded (no meaningful data is lost).