Module print

Module print 

Printing with email-specific line folding

Structs

Fmt
Fmt implements Formatter.
FmtConfig
Configuration passed when initializing a Fmt.

Constants

FMT_DEFAULT
FMT_NOFOLD

Traits

Formatter
An output formatter that can perform line folding and compute multipart boundaries.
Print

Functions

print_seq
print_to_vec
Prints a printable value as a Vec.
print_to_vec_with
Creates a formatter, passes it to f, and returns the corresponding output as a Vec.

Derive Macros

ToStringFromPrint