FmtConfig

Struct FmtConfig 

pub struct FmtConfig { /* private fields */ }
Configuration passed when initializing a Fmt.

line_limit defines the maximum line length allowed before trying to split. If set to None, there is no maximum line limit.

seed is used to seed the internal RNG which generates multipart boundaries. If set to None, the RNG is seeded using randomness from the operating system.

Implementations

Source

impl FmtConfig

pub const fn with_seed(self, seed: Option<u64>) -> Self

pub const fn with_line_limit(self, line_limit: Option<usize>) -> Self