pub fn date_time(input: &[u8]) -> IResult<&[u8], DateTime>Expand description
Read datetime
RFC grammar:
date-time = [ day-of-week "," ] date time [CFWS]
time = time-of-day zoneWe additionally allow dates with a missing zone (followed by end of input), which appear in some real world emails.
@FIXME - known bugs
-0000means NaiveDateTime, a date without a timezone while this library interprets it as +0000 aka UTC.- Obsolete military zones should be considered as NaiveTime due to an error in RFC0822 but are interpreted as their respective timezone according to the RFC5322 definition