pub struct FmtConfig { /* private fields */ }Expand description
Configuration passed when initializing a Fmt.
line_limit defines the maximum line length allowed before trying to split.
If set to None, there is no maximum line limit.
seed is used to seed the internal RNG which generates multipart
boundaries. If set to None, the RNG is seeded using randomness from
the operating system.
Implementations